@@ -1,6 +1,6 @@
 /* query-druid.c
  *
- * Copyright (C) 2004 - 2006 Vivien Malerba
+ * Copyright (C) 2004 - 2007 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -19,7 +19,8 @@
  */
 
 #include "query-druid.h"
-#include <libgnomedb/libgnomedb.h>
+#include <libgnomedb-graph/libgnomedb-graph.h>
+#include <libgnomedb-extra/libgnomedb-extra.h>
 #include <libgda/libgda.h>
 #include "workspace-page.h"
 #include "query-fields-editor.h"
