@@ -1,6 +1,6 @@
 /* query-editor.c
  *
- * Copyright (C) 2004 - 2006 Vivien Malerba
+ * Copyright (C) 2004 - 2007 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,7 +21,8 @@
 #include "query-editor.h"
 #include "query-fields-editor.h"
 #include "query-params-editor.h"
-#include <libgnomedb/gnome-db-editor.h>
+#include <libgnomedb-extra/gnome-db-editor.h>
+#include <libgnomedb-graph/libgnomedb-graph.h>
 
 static void query_editor_class_init (QueryEditorClass * class);
 static void query_editor_init (QueryEditor * wid);
@@ -488,8 +489,8 @@ query_changed_cb (GdaQuery *query, QueryEditor *qedit)
 		gtk_entry_set_text (GTK_ENTRY (qedit->priv->q_descr), "");
 
 	/* SQL version */
-	sql = gda_renderer_render_as_sql (GDA_RENDERER (qedit->priv->query), NULL, 
-					 GDA_RENDERER_EXTRA_PRETTY_SQL | GDA_RENDERER_EXTRA_VAL_ATTRS, NULL);
+	sql = gda_renderer_render_as_sql (GDA_RENDERER (qedit->priv->query), NULL, NULL,
+					  GDA_RENDERER_EXTRA_PRETTY_SQL | GDA_RENDERER_PARAMS_AS_DETAILED, NULL);
 	if (sql) {
 		gnome_db_editor_set_text (GNOME_DB_EDITOR (qedit->priv->sql_editor), sql, -1);
 		g_free (sql);
@@ -503,8 +504,9 @@ query_changed_cb (GdaQuery *query, QueryEditor *qedit)
 		sql = NULL;
 
 		if (cond) 
-			sql = gda_renderer_render_as_sql (GDA_RENDERER (cond), NULL, 
-							 GDA_RENDERER_EXTRA_PRETTY_SQL | GDA_RENDERER_EXTRA_VAL_ATTRS, NULL);
+			sql = gda_renderer_render_as_sql (GDA_RENDERER (cond), NULL, NULL,
+							  GDA_RENDERER_EXTRA_PRETTY_SQL | GDA_RENDERER_PARAMS_AS_DETAILED, 
+							  NULL);
 		if (sql) {
 			gnome_db_editor_set_text (GNOME_DB_EDITOR (qedit->priv->select_where), sql, -1);
 			g_free (sql);
