@@ -1,6 +1,6 @@
 /* query-fields-editor.c
  *
- * Copyright (C) 2004 - 2006 Vivien Malerba
+ * Copyright (C) 2004 - 2007 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -431,7 +431,7 @@ renderer_field_txt_edited_cb (GtkCellRendererText *renderer,
 		g_object_get (G_OBJECT (field), "gda-type", &gtype, NULL);
 		dh = gda_dict_get_default_handler (gda_object_get_dict ((GdaObject *) field), gtype);
 		value = gda_data_handler_get_value_from_sql (dh, new_text, 
-							     gda_query_field_value_get_g_type (GDA_QUERY_FIELD_VALUE (field)));
+							     gda_entity_field_get_g_type (GDA_ENTITY_FIELD (field)));
 		if (value) {
 			gda_query_field_value_set_value (GDA_QUERY_FIELD_VALUE (field), value);
 			gda_value_free (value);
@@ -476,7 +476,7 @@ renderer_field_filter_edited_cb (GtkCellRendererText *renderer,
 		newcond = gda_query_condition_new_from_sql (fedit->priv->query, new_text, NULL, &error);
 		if (!newcond) {
 			gchar *sql;
-			sql = gda_renderer_render_as_sql (GDA_RENDERER (field), NULL, 0, NULL);
+			sql = gda_renderer_render_as_sql (GDA_RENDERER (field), NULL, NULL, 0, NULL);
 			if (sql) {
 				gchar *text = g_strdup_printf ("%s %s", sql, new_text);
 				g_free (sql);
@@ -700,7 +700,7 @@ query_changed_cb (GdaQuery *query, QueryFieldsEditor *fedit)
 		}
 		
 		/* modify the model at iter */
-		sql = gda_renderer_render_as_sql (GDA_RENDERER (field), NULL, 0, NULL);
+		sql = gda_renderer_render_as_sql (GDA_RENDERER (field), NULL, NULL, 0, NULL);
 		order = gda_query_get_order_by_field (fedit->priv->query, field, &asc);
 		if (order >= 0) {
 			order_str = g_strdup_printf ("%d", order + 1);
@@ -709,9 +709,9 @@ query_changed_cb (GdaQuery *query, QueryFieldsEditor *fedit)
 		cond = g_object_get_data (G_OBJECT (field), "qf_filter_cond");
 		g_object_set_data (G_OBJECT (field), "qf_filter_cond", NULL);
 		if (cond) 
-			cond_sql = gda_renderer_render_as_sql (GDA_RENDERER (cond), NULL, 
-								    GDA_RENDERER_EXTRA_VAL_ATTRS,
-								    NULL);
+			cond_sql = gda_renderer_render_as_sql (GDA_RENDERER (cond), NULL, NULL,
+							       GDA_RENDERER_PARAMS_AS_DETAILED,
+							       NULL);
 		gtk_list_store_set (GTK_LIST_STORE (model), &iter,
 				    COLUMN_FIELD_PTR, field,
 				    COLUMN_FIELD_TXT, sql ? sql : gda_object_get_name (GDA_OBJECT (field)),
