@@ -1,6 +1,6 @@
 /* Mergeant
  *
- * Copyright (C) 1999 - 2006 Vivien Malerba
+ * Copyright (C) 1999 - 2007 Vivien Malerba
  * Copyright (C) 2002 - 2003 Rodrigo Moya
  *
  * Authors:
@@ -31,7 +31,7 @@
 #include <libgnomeui/gnome-about.h>
 #include <libgnomedb/libgnomedb.h>
 #include <libgnomedb/gnome-db-login-dialog.h>
-#include <libgnomedb/gnome-db-dbms-update-viewer.h>
+#include <libgnomedb-extra/gnome-db-dbms-update-viewer.h>
 #include "workspace.h"
 #include "workspace-window.h"
 #include <libgda/gda-threader.h>
@@ -94,12 +94,101 @@ on_file_copy_workspace (GtkAction *action, WorkspaceWindowPrivate *priv)
 	create_new_workspace_window (priv->dict);
 }
 
+static gboolean
+treat_close_request (WorkspaceWindowPrivate *priv)
+{
+	GtkWidget *window = priv->window;
+	GdaConnection *cnc;
+	GdaTransactionStatus *tstatus;
+	gboolean do_close = TRUE;
+	GList *list;
+
+	/* if the connection is used by another workspace, then allow closing of this window */
+	for (list = opened_workspaces; list; list = list->next) {
+		if (((WorkspaceWindowPrivate*) list->data != priv) &&
+		    (((WorkspaceWindowPrivate*) list->data)->dict == priv->dict))
+			return TRUE;
+	}
+	
+	/* if a transaction is started, then try to commit it */
+	g_assert (priv);
+	cnc = gda_dict_get_connection (priv->dict);
+	g_assert (cnc);
+	g_assert (gda_connection_is_opened (cnc));
+	tstatus = gda_connection_get_transaction_status (cnc);
+	if (tstatus) {
+		gchar *msg;
+		GtkWidget *dlg;
+		gint result;
+
+		msg = g_strdup_printf (_("<b>A transaction has been started on the %s connection.</b>\n\n"
+					 "if it is not committed, any change since the beginning of the "
+					 "transaction will be lost. \n\n"
+					 "<u>Rollback</u> the transaction to cancel any change made since the "
+					 "transaction was started, <u>commit</u> the transaction to save those changes, "
+					 "or <u>ignore</u> the transaction to let the DBMS handle the transaction (this "
+					 "usually leads to lose any change). What do you want to do?"), 
+				       gda_connection_get_dsn (cnc));
+		dlg = gtk_message_dialog_new_with_markup (GTK_WINDOW (window), GTK_DIALOG_MODAL,
+							  GTK_MESSAGE_WARNING,
+							  GTK_BUTTONS_NONE, msg);
+		g_free (msg);
+		gtk_dialog_add_buttons (GTK_DIALOG (dlg), _("Rollback transaction"), 1,
+					_("Commit transaction"), 2, 
+					_("Ignore transaction"), 3, NULL);
+		result = gtk_dialog_run (GTK_DIALOG (dlg));
+		gtk_widget_destroy (dlg);
+		if ((result == 1) || (result == 2)) {
+			GError *error = NULL;
+
+			dlg = NULL;
+			if (result == 1) {
+				if (!gda_connection_rollback_transaction (cnc, NULL, &error))
+					dlg = gtk_message_dialog_new_with_markup (GTK_WINDOW (window), GTK_DIALOG_MODAL,
+										  GTK_MESSAGE_ERROR,
+										  GTK_BUTTONS_NONE, 
+										  _("<b>Could not rollback current transaction:</b>"
+										    "\n%s\n\nWhat do you want to do?"),
+										  error && error->message ? 
+										  error->message : _("No detail"));
+			}
+			else {
+				if (gda_connection_commit_transaction (cnc, NULL, &error))
+					dlg = gtk_message_dialog_new_with_markup (GTK_WINDOW (window), GTK_DIALOG_MODAL,
+										  GTK_MESSAGE_ERROR,
+										  GTK_BUTTONS_NONE, 
+										  _("<b>Could not commit current transaction:</b>"
+										    "\n%s\n\nWhat do you want to do?"),
+										  error && error->message ? 
+										  error->message : _("No detail"));
+			}
+
+			if (error)
+				g_error_free (error);
+			if (dlg) {
+				gtk_dialog_add_buttons (GTK_DIALOG (dlg), _("Close anyway"), 1,
+							_("Don't close this workspace window"), 2, NULL);
+				result = gtk_dialog_run (GTK_DIALOG (dlg));
+				do_close = (result == 1) ? TRUE : FALSE;
+				gtk_widget_destroy (dlg);
+			}
+		}
+	}
+
+	return do_close;
+}
+
+static gboolean
+delete_event( GtkWidget *widget, GdkEvent *event, WorkspaceWindowPrivate *priv )
+{
+	return !treat_close_request (priv);
+}
+
 static void
 on_file_close (GtkAction *action, WorkspaceWindowPrivate *priv)
 {
-	GtkWidget *window = priv->window;
-	
-	gtk_widget_destroy (window);
+	if (treat_close_request (priv))
+		gtk_widget_destroy (priv->window);
 }
 
 static void
@@ -532,6 +621,8 @@ create_new_workspace_window_with_dict (GdaDict *dict, gboolean force_dbms_update
 
 	/* create the window */
 	priv->window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	g_signal_connect (G_OBJECT (priv->window), "delete_event",
+			  G_CALLBACK (delete_event), priv);
 	gtk_window_set_title (GTK_WINDOW (priv->window), "Mergeant");
 	g_object_set_data_full (G_OBJECT (priv->window), "Mergeant_WorkspaceWindowPrivate",
 				priv, (GDestroyNotify) destroy_private_data_cb);
