@@ -1,6 +1,6 @@
 /* Mergeant
  *
- * Copyright (C) 1999 - 2006 Vivien Malerba
+ * Copyright (C) 1999 - 2007 Vivien Malerba
  * Copyright (C) 2002 - 2003 Rodrigo Moya
  *
  * Authors:
@@ -29,6 +29,7 @@
 #include <gtk/gtktable.h>
 #include <gtk/gtkvpaned.h>
 #include <libgnomedb/libgnomedb.h>
+#include <libgnomedb-extra/libgnomedb-extra.h>
 #include "workspace.h"
 #include <string.h>
 #include "query-druid.h"
@@ -91,7 +92,7 @@ workspace_init (Workspace *wk, WorkspaceClass *klass)
 	wk->priv = g_new0 (WorkspacePrivate, 1);
 }
 
-static void dict_changed_ch (GdaDict *dict, Workspace *wk);
+static void dict_changed_cb (GdaDict *dict, Workspace *wk);
 static void
 workspace_dispose (GObject *object)
 {
@@ -132,7 +133,7 @@ workspace_finalize (GObject *object)
 	/* free memory */
 	if (wk->priv) {
 		g_signal_handlers_disconnect_by_func (G_OBJECT (wk->priv->dict),
-						      G_CALLBACK (dict_changed_ch), wk);
+						      G_CALLBACK (dict_changed_cb), wk);
 
 		g_free (wk->priv);
 		wk->priv = NULL;
@@ -217,7 +218,7 @@ workspace_set_dict (Workspace *wk, GdaDict *dict)
 
 	/* connecting to GdaDict's signals to handle auto saving */
 	g_signal_connect (G_OBJECT (dict), "changed",
-			  G_CALLBACK (dict_changed_ch), wk);
+			  G_CALLBACK (dict_changed_cb), wk);
 }
 
 
@@ -378,7 +379,7 @@ object_type_toggled_cb (GtkButton *button, Workspace *wk)
 }
 
 static void
-dict_changed_ch (GdaDict *dict, Workspace *wk)
+dict_changed_cb (GdaDict *dict, Workspace *wk)
 {
 	workspace_queue_dict_save (wk);	
 }
